# CHANGELOG

<!-- version list -->

## v2.0.0 (2025-10-13)

### Bug Fixes

- Repo
  ([`55e1eb5`](https://github.com/karlorz/futunn-helper/commit/55e1eb5b7765c266b7ad32d63d9e74f5666a805d))


## v1.0.0 (2025-10-13)

- Initial Release
